@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010, 2011 Igalia S.L.
+ * Copyright (C) 2010-2012 Igalia S.L.
  *
  * Contact: Iago Toral Quiroga <itoral@igalia.com>
  *
@@ -182,7 +182,7 @@ grl_metadata_key_setup_system_keys (GrlPluginRegistry *registry)
     grl_plugin_registry_register_metadata_key (registry,
                                                g_param_spec_string ("source",
                                                                     "Source",
-                                                                    "Source ID prioviding the content",
+                                                                    "Source ID providing the content",
                                                                     NULL,
                                                                     G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE),
                                                NULL);
