@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010, 2011 Igalia S.L.
+ * Copyright (C) 2010-2012 Igalia S.L.
  * Copyright (C) 2011 Intel Corporation.
  *
  * Contact: Iago Toral Quiroga <itoral@igalia.com>
@@ -89,22 +89,22 @@ enum {
   BROWSER_MODEL_CONTENT,
   BROWSER_MODEL_TYPE,
   BROWSER_MODEL_NAME,
-  BROWSER_MODEL_ICON,
+  BROWSER_MODEL_ICON
 };
 
 enum {
   METADATA_MODEL_NAME = 0,
-  METADATA_MODEL_VALUE,
+  METADATA_MODEL_VALUE
 };
 
 enum {
   SEARCH_MODEL_NAME = 0,
-  SEARCH_MODEL_SOURCE,
+  SEARCH_MODEL_SOURCE
 };
 
 enum {
   QUERY_MODEL_NAME = 0,
-  QUERY_MODEL_SOURCE,
+  QUERY_MODEL_SOURCE
 };
 
 typedef struct {
@@ -159,7 +159,7 @@ typedef struct {
     OP_TYPE_BROWSE,
     OP_TYPE_SEARCH,
     OP_TYPE_QUERY,
-    OP_TYPE_MULTI_SEARCH,
+    OP_TYPE_MULTI_SEARCH
   } type;
   guint offset;
   guint count;
@@ -1499,8 +1499,8 @@ set_flickr_config (void)
     grl_config_set_api_secret (config, FLICKR_SECRET);
     grl_config_set_api_token (config, token);
     grl_plugin_registry_add_config (registry, config, NULL);
-    g_free (token);
   }
+  g_free (token);
 }
 
 static void
@@ -1571,6 +1571,7 @@ ui_setup (void)
   /* Main window */
   view->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (view->window), WINDOW_TITLE);
+  gtk_window_resize (GTK_WINDOW (view->window), 600, 400);
   g_signal_connect (G_OBJECT (view->window), "destroy",
                     G_CALLBACK (gtk_main_quit), NULL);
 
@@ -1818,6 +1819,9 @@ show_plugins ()
 			BROWSER_MODEL_NAME, name,
 			BROWSER_MODEL_ICON, icon,
 			-1);
+    if (icon) {
+      g_object_unref (icon);
+    }
   }
   g_list_free (sources);
 }
